# **<project>**

Short description of the project.

<p align="center">
  <img src="assets/myproject.png" alt="General illustration of the project" width="60%"/>
</p>

# Why <project> ?

What is the initial motivation of this project ?

## Objective of the project

How this project will be considered achieved ?

# Table of Contents

-   [**Installation**](#installation)
-   [**Usage**](#usage)

# Installation

Make sure you have Python installed:

**1. (Optional) Create a virtual environment:**

```bash
python -m venv .env
```

**2. Install the package with pip in your terminal:**

```bash
pip install git+https://github.com/tboulet/<project>.git
```

# Usage

**Run the project with the following command:**

```bash
python -m <project>
```